import { fetchGuildChannels, Reminder } from "../../api";
import { useQuery } from "react-query";
import { useParams } from "wouter";
import { Name } from "./Name";
import { useState } from "preact/hooks";
import { EditButtonRow } from "./ButtonRow/EditButtonRow";
import { Message } from "./Message";
import { Settings } from "./Settings";
import { ReminderContext } from "./ReminderContext";

type Props = {
    reminder: Reminder;
};

export const EditReminder = ({ reminder: initialReminder }: Props) => {
    const { guild } = useParams();
    const [reminder, setReminder] = useState(initialReminder);

    const { isSuccess: channelsFetched, data: guildChannels } = useQuery(fetchGuildChannels(guild));

    const [collapsed, setCollapsed] = useState(false);

    if (!channelsFetched) {
        return <></>;
    }

    const channelInfo = guildChannels.find((c) => c.id === reminder.channel);

    return (
        <ReminderContext.Provider value={[reminder, setReminder]}>
            <div class={collapsed ? "reminderContent is-collapsed" : "reminderContent"}>
                <div class="columns is-mobile column reminder-topbar">
                    <div class="invert-collapses channel-bar">#{channelInfo.name}</div>
                    <Name value={reminder.name}></Name>
                    <div class="hide-button-bar">
                        <button
                            class="button hide-box"
                            onClick={() => {
                                setCollapsed(!collapsed);
                            }}
                        >
                            <span class="is-sr-only">Hide reminder</span>
                            <i class="fas fa-chevron-down"></i>
                        </button>
                    </div>
                </div>
                <div class="columns reminder-settings">
                    <Message />
                    <Settings />
                </div>
                <EditButtonRow></EditButtonRow>
            </div>
        </ReminderContext.Provider>
    );
};
